#!/usr/bin/python
import RPi.GPIO as GPIO
import time, os

LCD_RS = 7
LCD_E  = 8
LCD_D4 = 25
LCD_D5 = 24
LCD_D6 = 23
LCD_D7 = 18

GPIO.setmode(GPIO.BCM)
GPIO.setup(LCD_E,  GPIO.OUT)
GPIO.setup(LCD_RS, GPIO.OUT)
GPIO.setup(LCD_D4, GPIO.OUT)
GPIO.setup(LCD_D5, GPIO.OUT)
GPIO.setup(LCD_D6, GPIO.OUT)
GPIO.setup(LCD_D7, GPIO.OUT)

LCD_WIDTH = 16
LCD_LINE_1 = 0x80
LCD_LINE_2 = 0xC0
LCD_CHR = 1
LCD_CMD = 0
E_PULSE = 0.00005
E_DELAY = 0.00005
INIT  = 0.01
pause = 2

HD_1 = "/media/pi/7FDA-61CD"
HD_2 = "/media/pi/8CA8-C35A"
HD_3 = "/media/pi/A860-2E74"

def lcd_enable():
    time.sleep(E_DELAY)
    GPIO.output(LCD_E, 1)
    time.sleep(E_PULSE)
    GPIO.output(LCD_E, 0)
    time.sleep(E_DELAY)

def lcd_byte(bits, mode):
    GPIO.output(LCD_RS, mode)
    GPIO.output(LCD_D4, bits&0x10==0x10)
    GPIO.output(LCD_D5, bits&0x20==0x20)
    GPIO.output(LCD_D6, bits&0x40==0x40)
    GPIO.output(LCD_D7, bits&0x80==0x80)
    lcd_enable()
    GPIO.output(LCD_D4, bits&0x01==0x01)
    GPIO.output(LCD_D5, bits&0x02==0x02)
    GPIO.output(LCD_D6, bits&0x04==0x04)
    GPIO.output(LCD_D7, bits&0x08==0x08)
    lcd_enable()

def lcd_string(message):
    message = message.ljust(LCD_WIDTH," ")
    for i in range(LCD_WIDTH):
        lcd_byte(ord(message[i]),LCD_CHR)

def lcd_anzeige(z1, z2):
    lcd_byte(LCD_LINE_1, LCD_CMD)
    lcd_string(z1)
    lcd_byte(LCD_LINE_2, LCD_CMD)
    lcd_string(z2)

LCD_INIT = [0x33, 0x33, 0x32, 0x28, 0x0C, 0x06, 0x01]
for i in LCD_INIT:
    lcd_byte(i,LCD_CMD)
    time.sleep(INIT)

try:
  while True:
    sd1 = os.statvfs('/')
    hd1 = os.statvfs(HD_1)
    hd2 = os.statvfs(HD_2)
    hd3 = os.statvfs(HD_3)
    sd1x = sd1.f_bsize * sd1.f_bavail // 1048576
    hd1x = hd1.f_bsize * hd1.f_bavail // 1048576
    hd2x = hd2.f_bsize * hd2.f_bavail // 1048576
    hd3x = hd3.f_bsize * hd3.f_bavail // 1048576
    zeile1 = time.asctime()
    zeile2 = os.popen("hostname -I").readline()[:-2]
    lcd_anzeige(zeile1, zeile2)
    time.sleep(pause)
    zeile1 = "S:" + str(sd1x) + "MB "
    zeile1 += "2:" + str(hd2x) + "MB"
    zeile2 = "1:" + str(hd1x) + "MB "
    zeile2 += "3:" + str(hd3x) + "MB"
    lcd_anzeige(zeile1, zeile2)
    time.sleep(pause)
except KeyboardInterrupt:
  GPIO.cleanup()
